@@ -13,6 +13,8 @@ import (
 	"github.com/containers/storage/pkg/chunked/compressor"
 	"github.com/containers/storage/pkg/ioutils"
 	"github.com/containers/storage/pkg/mflag"
+	digest "github.com/opencontainers/go-digest"
+	"github.com/sirupsen/logrus"
 )
 
 var (
@@ -155,7 +157,10 @@ func applyDiffUsingStagingDirectory(flags *mflag.FlagSet, action string, m stora
 		return 1, err
 	}
 
-	if _, err := io.Copy(compressor, tr); err != nil {
+	digesterCompressed := digest.Canonical.Digester()
+	r := io.TeeReader(tr, digesterCompressed.Hash())
+
+	if _, err := io.Copy(compressor, r); err != nil {
 		return 1, err
 	}
 	if err := compressor.Close(); err != nil {
@@ -171,18 +176,26 @@ func applyDiffUsingStagingDirectory(flags *mflag.FlagSet, action string, m stora
 		file: tar,
 	}
 
-	differ, err := chunked.GetDiffer(context.Background(), m, size, metadata, &fetcher)
+	differ, err := chunked.GetDiffer(context.Background(), m, digesterCompressed.Digest(), size, metadata, &fetcher)
 	if err != nil {
 		return 1, err
 	}
 
-	var options graphdriver.ApplyDiffOpts
-	out, err := m.ApplyDiffWithDiffer("", &options, differ)
+	var options graphdriver.ApplyDiffWithDifferOpts
+	out, err := m.PrepareStagedLayer(&options, differ)
 	if err != nil {
 		return 1, err
 	}
-	if err := m.ApplyDiffFromStagingDirectory(layer, out.Target, out, &options); err != nil {
-		m.CleanupStagingDirectory(out.Target)
+
+	applyStagedLayerArgs := storage.ApplyStagedLayerOptions{
+		ID:          layer,
+		DiffOutput:  out,
+		DiffOptions: &options,
+	}
+	if _, err := m.ApplyStagedLayer(applyStagedLayerArgs); err != nil {
+		if err := m.CleanupStagedLayer(out); err != nil {
+			logrus.Warnf("cleanup of the staged layer failed: %v", err)
+		}
 		return 1, err
 	}
 	return 0, nil
