@@ -1,5 +1,4 @@
 //go:build linux || freebsd || solaris
-// +build linux freebsd solaris
 
 package graphtest
 
@@ -44,6 +43,22 @@ type Driver struct {
 	refCount int
 }
 
+func newGraphDriver(t testing.TB, name string, options []string, root string, runroot string) graphdriver.Driver {
+	d, err := graphdriver.GetDriver(name, graphdriver.Options{DriverOptions: options, Root: root, RunRoot: runroot})
+	if err != nil {
+		t.Logf("graphdriver: %v\n", err)
+		if errors.Is(err, graphdriver.ErrNotSupported) || errors.Is(err, graphdriver.ErrPrerequisites) || errors.Is(err, graphdriver.ErrIncompatibleFS) {
+			t.Skipf("Driver %s not supported", name)
+		}
+		var unixErr unix.Errno
+		if errors.As(err, &unixErr) && unixErr == unix.EPERM {
+			t.Skipf("Insufficient permission to test %s", name)
+		}
+		t.Fatal(err)
+	}
+	return d
+}
+
 func newDriver(t testing.TB, name string, options []string) *Driver {
 	root, err := os.MkdirTemp("", "storage-graphtest-")
 	require.NoError(t, err)
@@ -51,15 +66,7 @@ func newDriver(t testing.TB, name string, options []string) *Driver {
 	require.NoError(t, err)
 
 	require.NoError(t, os.MkdirAll(root, 0o755))
-	d, err := graphdriver.GetDriver(name, graphdriver.Options{DriverOptions: options, Root: root, RunRoot: runroot})
-	if err != nil {
-		t.Logf("graphdriver: %v\n", err)
-		if errors.Is(err, graphdriver.ErrNotSupported) || errors.Is(err, graphdriver.ErrPrerequisites) || errors.Is(err, graphdriver.ErrIncompatibleFS) {
-			t.Skipf("Driver %s not supported", name)
-		}
-		t.Fatal(err)
-	}
-	return &Driver{d, root, runroot, 1}
+	return &Driver{newGraphDriver(t, name, options, root, runroot), root, runroot, 1}
 }
 
 func cleanup(t testing.TB, d *Driver) {
@@ -80,6 +87,13 @@ func GetDriver(t testing.TB, name string, options ...string) graphdriver.Driver
 	return drv
 }
 
+func ReconfigureDriver(t testing.TB, name string, options ...string) {
+	if err := drv.Cleanup(); err != nil {
+		t.Fatal(err)
+	}
+	drv.Driver = newGraphDriver(t, name, options, drv.root, drv.runroot)
+}
+
 // PutDriver removes the driver if it is no longer used and updates the reference count.
 func PutDriver(t testing.TB) {
 	if drv == nil {
@@ -116,7 +130,8 @@ func DriverTestCreateEmpty(t testing.TB, drivername string, driverOptions ...str
 	require.NoError(t, err)
 	assert.Len(t, fis, 0)
 
-	driver.Put("empty")
+	err = driver.Put("empty")
+	require.NoError(t, err)
 }
 
 // DriverTestCreateBase create a base driver and verify.
@@ -147,7 +162,8 @@ func DriverTestCreateSnap(t testing.TB, drivername string, driverOptions ...stri
 	assert.NoError(t, err)
 	err = os.Chmod(root, modifiedPerms)
 	require.NoError(t, err)
-	driver.Put("Snap2")
+	err = driver.Put("Snap2")
+	require.NoError(t, err)
 
 	err = driver.Create("SecondSnap", "Snap2", nil)
 	require.NoError(t, err)
@@ -188,17 +204,13 @@ func DriverTestCreateFromTemplate(t testing.TB, drivername string, driverOptions
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err = checkChanges(noChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, noChanges, changes)
 
 	changes, err = driver.Changes("ROFromTemplate", nil, "Snap3", nil, "")
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err = checkChanges(noChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, noChanges, changes)
 
 	if err := checkFile(driver, "FromTemplate", "testfile.txt", content); err != nil {
 		t.Fatal(err)
@@ -219,25 +231,19 @@ func DriverTestCreateFromTemplate(t testing.TB, drivername string, driverOptions
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err = checkChanges(expectedChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, expectedChanges, changes)
 
 	changes, err = driver.Changes("FromTemplate", nil, "Base3", nil, "")
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err = checkChanges(expectedChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, expectedChanges, changes)
 
 	changes, err = driver.Changes("ROFromTemplate", nil, "Base3", nil, "")
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err = checkChanges(expectedChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, expectedChanges, changes)
 
 	verifyBase(t, driver, "Base3", defaultPerms)
 }
@@ -400,10 +406,7 @@ func DriverTestChanges(t testing.TB, drivername string, driverOptions ...string)
 	if err != nil {
 		t.Fatal(err)
 	}
-
-	if err = checkChanges(expectedChanges, changes); err != nil {
-		t.Fatal(err)
-	}
+	require.ElementsMatch(t, expectedChanges, changes)
 }
 
 func writeRandomFile(path string, size uint64) error {
@@ -496,10 +499,7 @@ func DriverTestEcho(t testing.TB, drivername string, driverOptions ...string) {
 		if err != nil {
 			t.Fatal(err)
 		}
-
-		if err = checkChanges(expectedChanges, changes); err != nil {
-			t.Fatal(err)
-		}
+		require.ElementsMatch(t, expectedChanges, changes)
 
 		if err := driver.Create(second, base, nil); err != nil {
 			t.Fatal(err)
@@ -523,10 +523,7 @@ func DriverTestEcho(t testing.TB, drivername string, driverOptions ...string) {
 		if err != nil {
 			t.Fatal(err)
 		}
-
-		if err = checkChanges(expectedChanges, changes); err != nil {
-			t.Fatal(err)
-		}
+		require.ElementsMatch(t, expectedChanges, changes)
 
 		if err = driver.Create(third, second, nil); err != nil {
 			t.Fatal(err)
@@ -556,10 +553,7 @@ func DriverTestEcho(t testing.TB, drivername string, driverOptions ...string) {
 		if err != nil {
 			t.Fatal(err)
 		}
-
-		if err = checkChanges(expectedChanges, changes); err != nil {
-			t.Fatal(err)
-		}
+		require.ElementsMatch(t, expectedChanges, changes)
 
 		err = driver.Put(third)
 		if err != nil {
