@@ -6,18 +6,8 @@ import (
 
 	"github.com/containers/storage/pkg/idtools"
 	"github.com/google/go-intervals/intervalset"
-	"github.com/stretchr/testify/assert"
 )
 
-func TestMinMaxInt(t *testing.T) {
-	assert.Equal(t, 5, minInt(5, 8))
-	assert.Equal(t, 3, minInt(10, 3))
-	assert.Equal(t, 2, minInt(2, 2))
-	assert.Equal(t, 8, maxInt(5, 8))
-	assert.Equal(t, 10, maxInt(10, 3))
-	assert.Equal(t, 2, maxInt(2, 2))
-}
-
 func allIntervals(s *idSet) []interval {
 	iterator, cancel := s.iterator()
 	defer cancel()
@@ -685,7 +675,7 @@ func TestIntervalIsZero(t *testing.T) {
 	}
 }
 
-// assertIntervalSame aserts `got` equals to `want` considering zero check. If the wanted interval
+// assertIntervalSame asserts `got` equals to `want` considering zero check. If the wanted interval
 // is empty, we only want to assert IsZero() == true, instead of the exact number.
 func assertIntervalSame(t *testing.T, got intervalset.Interval, want *interval, name string) {
 	t.Helper()
