@@ -5,6 +5,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"runtime"
 	"sync"
 	"sync/atomic"
 	"testing"
@@ -221,6 +222,62 @@ func TestLockfileName(t *testing.T) {
 	assert.NotEmpty(t, l.name, "lockfile name should be recorded correctly")
 }
 
+func TestTryWriteLockFile(t *testing.T) {
+	runtime.LockOSThread()
+	defer runtime.UnlockOSThread()
+
+	l, err := getTempLockfile()
+	require.Nil(t, err, "error getting temporary lock file")
+	defer os.Remove(l.name)
+
+	err = l.TryLock()
+	assert.Nil(t, err)
+
+	l.AssertLocked()
+
+	errChan := make(chan error)
+	go func() {
+		errChan <- l.TryRLock()
+		errChan <- l.TryLock()
+	}()
+	assert.NotNil(t, <-errChan)
+	assert.NotNil(t, <-errChan)
+
+	l.Unlock()
+}
+
+func TestTryReadLockFile(t *testing.T) {
+	runtime.LockOSThread()
+	defer runtime.UnlockOSThread()
+
+	l, err := getTempLockfile()
+	require.Nil(t, err, "error getting temporary lock file")
+	defer os.Remove(l.name)
+
+	err = l.TryRLock()
+	assert.Nil(t, err)
+
+	l.AssertLocked()
+
+	errChan := make(chan error)
+	go func() {
+		errChan <- l.TryRLock()
+		l.Unlock()
+
+		errChan <- l.TryLock()
+	}()
+	assert.Nil(t, <-errChan)
+	assert.NotNil(t, <-errChan)
+
+	l.Unlock()
+
+	go func() {
+		errChan <- l.TryLock()
+		l.Unlock()
+	}()
+	assert.Nil(t, <-errChan)
+}
+
 func TestLockfileRead(t *testing.T) {
 	l, err := getTempLockfile()
 	require.Nil(t, err, "error getting temporary lock file")
@@ -363,7 +420,7 @@ func TestLockfileWriteConcurrent(t *testing.T) {
 	var wg sync.WaitGroup
 	var highestMutex sync.Mutex
 	var counter, highest int64
-	for i := 0; i < 8000; i++ {
+	for range 8000 {
 		wg.Add(1)
 		go func() {
 			l.Lock()
@@ -399,7 +456,7 @@ func TestLockfileReadConcurrent(t *testing.T) {
 	unlocked := make(chan bool)
 	done := make(chan bool)
 
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		go func() {
 			l.RLock()
 			locked <- true
@@ -410,15 +467,15 @@ func TestLockfileReadConcurrent(t *testing.T) {
 	}
 
 	// Wait for all parallel locks to succeed
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		<-locked
 	}
 	// Instruct all parallel locks to unlock
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		unlocked <- true
 	}
 	// Wait for all parallel locks to be unlocked
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		<-done
 	}
 }
@@ -439,7 +496,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 	// A writer always adds `diff` to the counter. Hence, `diff` is the
 	// only valid value in the critical section.
 	writer := func(c *int32) {
-		for i := 0; i < numIterations; i++ {
+		for range numIterations {
 			l.Lock()
 			tmp := atomic.AddInt32(c, diff)
 			assert.True(t, tmp == diff, "counter should be %d but instead is %d", diff, tmp)
@@ -453,7 +510,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 	// A reader always adds `1` to the counter. Hence,
 	// [1,`numReaders*numIterations`] are valid values.
 	reader := func(c *int32) {
-		for i := 0; i < numIterations; i++ {
+		for range numIterations {
 			l.RLock()
 			tmp := atomic.AddInt32(c, 1)
 			assert.True(t, tmp >= 1 && tmp < diff)
@@ -472,7 +529,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 		}
 	}
 
-	for i := 0; i < numReaders+numWriters; i++ {
+	for range numReaders + numWriters {
 		<-done
 	}
 }
