@@ -5,11 +5,9 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"reflect"
 	"strings"
 	"testing"
 
-	"github.com/containers/storage/pkg/idtools"
 	"github.com/containers/storage/pkg/unshare"
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/require"
@@ -37,7 +35,7 @@ func TestGetRootlessStorageOpts(t *testing.T) {
 
 		assert.NilError(t, err)
 		expectedDriver := vfsDriver
-		if canUseRootlessOverlay(home, runhome) {
+		if canUseRootlessOverlay() {
 			expectedDriver = overlayDriver
 		}
 		assert.Equal(t, storageOpts.GraphDriverName, expectedDriver)
@@ -83,14 +81,6 @@ func TestGetRootlessStorageOpts(t *testing.T) {
 		assert.Assert(t, storageOpts.GraphDriverName == overlayDriver || storageOpts.GraphDriverName == vfsDriver, fmt.Sprintf("The rootless driver should be set to 'overlay' or 'vfs' not '%v'", storageOpts.GraphDriverName))
 	})
 
-	t.Run("systemDriver=devmapper", func(t *testing.T) {
-		systemOpts := StoreOptions{}
-		systemOpts.GraphDriverName = "devmapper"
-		storageOpts, err := getRootlessStorageOpts(systemOpts)
-		assert.NilError(t, err)
-		assert.Assert(t, storageOpts.GraphDriverName == overlayDriver || storageOpts.GraphDriverName == vfsDriver, fmt.Sprintf("The rootless driver should be set to 'overlay' or 'vfs' not '%v'", storageOpts.GraphDriverName))
-	})
-
 	t.Run("systemDriver=zfs", func(t *testing.T) {
 		systemOpts := StoreOptions{}
 		systemOpts.GraphDriverName = "zfs"
@@ -134,75 +124,6 @@ func TestGetRootlessStorageOpts2(t *testing.T) {
 	assert.Equal(t, storageOpts.GraphRoot, expectedPath)
 }
 
-func TestSetRemapUIDsGIDsOpts(t *testing.T) {
-	var remapOpts StoreOptions
-	uidmap := []idtools.IDMap{
-		{
-			ContainerID: 0,
-			HostID:      1000000000,
-			Size:        30000,
-		},
-	}
-	gidmap := []idtools.IDMap{
-		{
-			ContainerID: 0,
-			HostID:      1500000000,
-			Size:        60000,
-		},
-	}
-
-	err := ReloadConfigurationFile("./storage_test.conf", &remapOpts)
-	require.NoError(t, err)
-	if !reflect.DeepEqual(uidmap, remapOpts.UIDMap) {
-		t.Errorf("Failed to set UIDMap: Expected %v Actual %v", uidmap, remapOpts.UIDMap)
-	}
-	if !reflect.DeepEqual(gidmap, remapOpts.GIDMap) {
-		t.Errorf("Failed to set GIDMap: Expected %v Actual %v", gidmap, remapOpts.GIDMap)
-	}
-}
-
-func TestSetRemapUserGroupOpts(t *testing.T) {
-	var remapOpts StoreOptions
-
-	user := os.Getenv("USER")
-	if user == "root" {
-		t.Skip("This test is enabled only rootless user")
-	}
-
-	configPath := "./remap_user_test.conf"
-	config := fmt.Sprintf(`
-[storage]
-driver = ""
-
-[storage.options]
-remap-uids = "0:1000000000:30000"
-remap-gids = "0:1500000000:60000"
-
-remap-user = "%s"
-remap-group = "%s"
-`, user, user)
-	f, err := os.Create(configPath)
-	require.NoError(t, err)
-	defer func() {
-		f.Close()
-		os.Remove(configPath)
-	}()
-
-	_, err = f.Write([]byte(config))
-	require.NoError(t, err)
-
-	mappings, err := idtools.NewIDMappings(user, user)
-	require.NoError(t, err)
-	err = ReloadConfigurationFile(configPath, &remapOpts)
-	require.NoError(t, err)
-	if !reflect.DeepEqual(mappings.UIDs(), remapOpts.UIDMap) {
-		t.Errorf("Failed to set UIDMap: Expected %v Actual %v", mappings.UIDs(), remapOpts.UIDMap)
-	}
-	if !reflect.DeepEqual(mappings.GIDs(), remapOpts.GIDMap) {
-		t.Errorf("Failed to set GIDMap: Expected %v Actual %v", mappings.GIDs(), remapOpts.GIDMap)
-	}
-}
-
 func TestReloadConfigurationFile(t *testing.T) {
 	content := bytes.NewBufferString("")
 	logrus.SetOutput(content)
